function [ ] = DCsweep(opt, Nsweep)
% DCsweep(opt, Nsweep)
%
% DCseep.m produces DC response plots for cavity length change.
%
% 1. Total DC power at several ports defined 'nDC' in "setup.m".
% 2. DC power for each carrier and RF sideband at certain port.
% 3. Demodulated signals.

global rd PFf

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting

  % Check number of input arguments
  if nargin < 2
    Nsweep = 51;
  elseif Nsweep < 51
    Nsweep = 51;
  end

  eval([char(PFf), '_setup']);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% DC sweep
  for pn = 1 : length(PN)
    pos = zeros(opt.Noptic, 1);
    clear [xPos, sigDC, fDC];
    switch pn
      case Lp
        pos(nEX) = 1e-10; pos(nEY) = 1e-10;     % drive mirrors [m]
        dr=nEX;
        posoff = (opt.optic(nEX).pos + opt.optic(nEY).pos) / 2;
        n = getFieldAt(opt, nREFLpd, 'in');		% PR back output field
      case Lm
        pos(nEX) = 1e-11; pos(nEY) = -1e-11;    % drive mirrors [m]
        dr=nEX;
        posoff = (opt.optic(nEX).pos - opt.optic(nEY).pos) / 2;
%        n = getFieldAt(opt, nOMCpd, 'in');       % SR back output field
        n = getFieldAt(opt, nASpd, 'in');       % SR back output field
      case lp
        pos(nPR) = 1e-7;                        % drive mirrors [m]
        dr=nPR;
        posoff = opt.optic(nPR).pos;
        n = getFieldAt(opt, nPR, 'fr');         % PR front input field
      case lm
        pos(nEX) = 1e-7; pos(nEY) = -pos(nEX); pos(nIX) = -pos(nEX); pos(nIY) = pos(nEX);
        dr=nEX;
%        pos(nBS) = 5e-8; pos(nPR) = -sqrt(2) * pos(nBS); pos(nSR) = -sqrt(2) *pos(nBS);
%        dr=nBS;
        n = getFieldAt(opt, nOMCpd, 'in');		% SR front input field
      case lsr
        pos(nSR) = 5e-7;                        % drive mirrors [m]
        dr=nSR;
        posoff = opt.optic(nSR).pos - opt.lambda/4*0;
        %n = getFieldAt(opt, nPOXpd, 'in');		% POX PD input field
        n = getFieldAt(opt, nSR, 'fr');		% SR front input field
    end

    [xPos, sigDC, fDC] = sweepDC(opt, -pos, pos, Nsweep);

    if isempty(findstr('HD', opt.probe(PN(pn)).name)) % not homodyne
      if isempty(findstr('IM', opt.probe(PN(pn)).name)) % not double demod
        if isempty(findstr('DC', opt.probe(PN(pn)).name)) % not DC readout
          % single demod
          Nmid = find(xPos(dr, :) >= -1e-16, 1);
          if isempty(findstr('Q', opt.probe(PN(pn)).name)) % I-phase
            npd = [PN(pn); PN(pn)+1];
            %phase1 = -180 * atan2(sigDC(PN(pn)+1, Nmid), sigDC(PN(pn), Nmid)) / pi;
          else % Q-phase
            npd = [PN(pn)-1; PN(pn)];
            %phase1 = -180 * atan2(sigDC(PN(pn)-1, Nmid), sigDC(PN(pn), Nmid)) / pi;
          end
          %str = sprintf('%s demod phase errors: %g dg for %s', char(NC(pn)), phase1, prbNames{PN(pn)});
          %disp(str)
          %phase1 = opt.probe(PN(pn)).phase - phase1;
          %str = sprintf('  "good" phases: %g dg for %s', phase1, prbNames{PN(pn)});
          %disp(str)
        else
          % DC readout
          npd = PN(pn);
        end
      else
        % double demod
        npd = [PN(pn); PN(pn)+1; PN(pn)+2; PN(pn)+3];
      end
    else
      % Homodyne detection
      npd = [PN(pn); PN(pn)+1];
    end
    
    % make plots
    %
    h = figure(100 + pn);
    scrsz = get(0,'ScreenSize');
    figpos = get(h, 'Position');
    if figpos == [420   528   560   420]
      set(h, 'Position',[scrsz(3)/2-560/2 scrsz(4)*0.05 560 scrsz(4)*0.85])
    end
    clf

    % DC power
    subplot(3, 1, 1)
    semilogy((xPos(dr, :) + posoff) / opt.lambda * 360, sigDC(nDC, :) * qeff)
    lineAtX((posoff) / opt.lambda * 360, 'k')
    legend(prbNames(nDC), 2)
    title([char(NC(pn)) ' sweep: DC signals'])
    ylabel('power [W]')
    %axis tight
    grid on

    % RF power
    subplot(3, 1, 2)
    fDCp = permute(fDC, [2, 3, 1]);
    semilogy((xPos(dr, :) + posoff) / opt.lambda * 360, abs((fDCp(nSBa, :, n))).^2 * qeff)%, ...
    lineAtX((posoff) / opt.lambda * 360, 'k')
    title([char(NC(pn)) ' sweep: RF component powers at ' getSinkName(opt, n)])
    ylabel('power [W]')
    legend(num2str(vFrf(nSBa) / 1e6), 2)
    %axis tight
    grid on
  
    % signal
    subplot(3, 1, 3)
    if isempty(findstr('IM', opt.probe(PN(pn)).name)) % single demod
      if isempty(findstr('HD', opt.probe(PN(pn)).name)) % single demod
        plot((xPos(dr, :) + posoff) / opt.lambda * 360, sigDC(npd, :) * qeff)
        lineAtX((posoff) / opt.lambda * 360, 'k')
        legend(prbNames(npd), 2)
      else % homodyne
        %plot((xPos(dr, :) + posoff)/ opt.lambda * 360, sigDC(npd, :))
        %hold on
        plot((xPos(dr, :) + posoff) / opt.lambda * 360, (sigDC(npd(1), :) - sigDC(npd(2), :)) * qeff, 'k')
        lineAtX((posoff) / opt.lambda * 360, 'k')
        legend('HD total(a-b)', 2)
        %hold off
      end
    else  % double demod
      plot((xPos(dr, :) + posoff)/ opt.lambda * 360, sigDC(npd, :) * qeff)
      hold on
      plot((xPos(dr, :) + posoff) / opt.lambda * 360, (sigDC(npd(1), :) + sigDC(npd(3), :)) * qeff, 'k')
      lineAtX((posoff) / opt.lambda * 360, 'k')
      legend([prbNames(npd), 'DDM (IM+IP)'], 2)
      hold off
    end
    title([char(NC(pn)) ' sweep: error signals'])
    xlabel('phase [deg]')
    ylabel('power [W]')
    %axis tight
    grid on
    h = gcf;
    for ns = 1 : length(ext)
      saveas(h, [rd '/' num2str(100 + pn) '_DCsweep_' char(NC(pn))  '.' char(ext(ns))]);
    end
  end