function [RePhaseOn] = contourplot(opt, f, sigDC, hL, PN)
% [RePhaseOn] = contourplot(opt, f, sigDC, hL )
%
% contourplot.m produces coutour plots for DDM signals. The coutour plots
% consist of;
%
% 1. DC offset of demodulated signal [W]
% 2. slope of demodulated signal (demodulated signal / cavity length
%    change) for l+ (PRC) as a unit of [W/m] at certain frequency (default 0.1Hz) .
% 3. slope of demodulated signal for l- (MICH) [W/m]
% 4. slope of demodulated signal for ls (SRC) [W/m]

global rd PFf

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting

  eval([char(PFf), '_setup']);
  warning off all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

  phs = (-180:1:180)';
  [ph1,ph2] = meshgrid(-180:10:180,-180:10:180);
  RePhaseOn = 0;
  
  for pn = 1:length(PN)
    clear ff
    for n = 1 : 1
      fp(n) = find(f(:) > 0.1*10^(n-1),1);
    end
    for n = 1:length(fp)
      if isempty(findstr('IM', opt.probe(PN(pn)).name))
        if isempty(findstr('DC', opt.probe(PN(pn)).name))
          %%% Dem phase plot for single demod
          clear phase1 phase1a
          if isempty(findstr('Q', opt.probe(PN(pn)).name))
            phase1 = -180 * atan2(hL(fp(n)-1, PN(pn)+1, LN(pn)), hL(fp(n)-1, PN(pn), LN(pn))) / pi;
          else
            phase1 =  180 * atan2(hL(fp(n)-1, PN(pn)-1, LN(pn)), hL(fp(n)-1, PN(pn), LN(pn))) / pi;
          end
          phase1a = opt.probe(PN(pn)).phase - phase1;
          if phase1a > 180
            phase1a = phase1a - 180;
          end
          if phase1a < -180
            phase1a = phase1a + 180;
          end
          str = sprintf('\n%s current demod phase: %g degree', char(NC(LN(pn))), opt.probe(PN(pn)).phase);
          disp(str)
          str = sprintf('  "good" phase: %g dg for %s', phase1a, prbNames{PN(pn)});
          disp(str)
          str = sprintf('  %s demod phase errors: %g degree for %s', char(NC(LN(pn))), phase1a - opt.probe(PN(pn)).phase, prbNames{PN(pn)});
          disp(str)

          %%% Plots
          figure(200 + (n-1)*10 + pn)
          clf
          if isempty(findstr('Q', opt.probe(PN(pn)).name))
            dd = (sigDC(PN(pn),   1) .* cos((phs - opt.probe(PN(pn)  ).phase) / 180*pi)...
               +  sigDC(PN(pn)+1, 1) .* sin((phs - opt.probe(PN(pn)  ).phase) / 180*pi)) * 1e2;
            for cn = 1 : length(PN)
              sd(:, cn) = (hL(fp(n)-1, PN(pn),   cn) .* cos((phs - opt.probe(PN(pn)  ).phase) / 180*pi)...
                        +  hL(fp(n)-1, PN(pn)+1, cn) .* sin((phs - opt.probe(PN(pn)  ).phase) / 180*pi)) / 1e7;
            end
          else
            dd = (sigDC(PN(pn)-1, 1) .* cos((phs - opt.probe(PN(pn)-1).phase) / 180*pi)...
               +  sigDC(PN(pn),   1) .* sin((phs - opt.probe(PN(pn)-1).phase) / 180*pi)) * 1e2;
            for cn = 1 : length(PN)
              sd(:, cn) = (hL(fp(n)-1, PN(pn)-1, cn) .* cos((phs - opt.probe(PN(pn)-1).phase) / 180*pi)...
                        +  hL(fp(n)-1, PN(pn),   cn) .* sin((phs - opt.probe(PN(pn)-1).phase) / 180*pi)) / 1e7;
            end
          end
          plot(phs, [sd, dd], 'LineWidth', 2)
          lineAtX(opt.probe(PN(pn)).phase, 'k')
          clear lg
          for b = 1 : length(PN)
            lg(b) = {strcat(char(NC(b)), '[1e7W/m]')};
          end
          lg(b+1) = {'DC[1e-2W]'};
          legend(lg)
          xlabel('Demodulation Phase [deg]')
          ylabel(['Signal in ' num2str(f(fp(n)-1)) 'Hz'])
          title([char(NC(LN(pn))) ' signals (slope and DC) at ' char(ND(pn))])
          grid on
          v = axis;
          axis([-180 180 v(3) v(4)])
          h = gcf;
          for ns = 1 : length(ext)
            saveas(h, [rd '/' num2str(200 + (n-1)*10 + pn) '_SDM_' char(NC(LN(pn)))  '.' char(ext(ns))]);
          end
                    
          % Phase compensations
          if abs(phase1a - opt.probe(PN(pn)).phase) > 1
            str = sprintf('%s phase difference at %s is more than 1 degree.', char(NC(LN(pn))), prbNames{PN(pn)});
            disp(str) 
            c1 = input('Do you want to replace old phase to new good phase? or put phase you want in degree y/n/phase[deg] [n]: ', 'S');
            if c1 == 'y' | isreal(c1)
              RePhaseOn = 1;
              if isempty(findstr('7f1', opt.probe(PN(pn)).name))
              if isempty(findstr('3f2', opt.probe(PN(pn)).name))
                if isempty(findstr('3f1', opt.probe(PN(pn)).name))
                  if isempty(findstr('2', opt.probe(PN(pn)).name))
                    phname = strcat('ph', PNr(pn), '1');
                  else
                    phname = strcat('ph', PNr(pn), '2');
                  end
                else
                  phname = strcat('ph', PNr(pn), '3f1');
                end
              else
                phname = strcat('ph', PNr(pn), '3f2');
              end
              else
                phname = strcat('ph', PNr(pn), '7f1');
              end
                
              fid = fopen([char(PFf) '_demph.m'], 'a');
              if c1 == 'y'
                if isempty(findstr('Q', opt.probe(PN(pn)).name))
                  fprintf(fid, '%s = %g;\n', char(phname), phase1a);
                else
                  fprintf(fid, '%s = %g;\n', char(phname), phase1a - 90);
                end
              else
                if isempty(findstr('Q', opt.probe(PN(pn)).name))
                  fprintf(fid, '%s = %g;\n', char(phname), str2num(c1));
                else
                  fprintf(fid, '%s = %g;\n', char(phname), str2num(c1) - 90);
                end
              end
              fclose(fid);
            end    
          end
        end

      else
        %%% Contour plot for DDM
        % compute phase errors for each double-demod signals
        clear phaseM phaseP
        phaseM = -180 * atan2(hL(fp(n)-1, PN(pn)+1, LN(pn)), hL(fp(n)-1, PN(pn)  , LN(pn))) / pi;
        phaseP = -180 * atan2(hL(fp(n)-1, PN(pn)+3, LN(pn)), hL(fp(n)-1, PN(pn)+2, LN(pn))) / pi;

        phaseMa = opt.probe(PN(pn)  ).phase - phaseM;
        phasePa = opt.probe(PN(pn)+2).phase - phaseP;
        if phaseMa > 180
          phaseMa = phaseMa - 180;
        end
        if phaseMa < -180
          phaseMa = phaseMa + 180;
        end
        if phasePa > 180
          phasePa = phasePa - 180;
        end
        if phasePa < -180
          phasePa = phasePa + 180;
        end

        str = sprintf('\n%s current demod phase: %g degree for for %s, %g degree for for %s',...
              char(NC(LN(pn))), opt.probe(PN(pn)  ).phase, prbNames{PN(pn)}, opt.probe(PN(pn)+2).phase, prbNames{PN(pn)+2});
        disp(str)
        str = sprintf('  "good phase: %g dg for %s, %g dg for %s', ...
                       phaseMa, prbNames{PN(pn)}, phasePa, prbNames{PN(pn)+2});
        disp(str)      
        str = sprintf('%s double-demod phase errors: %g dg for %s, %g dg for %s', ...
                        char(NC(LN(pn))), phaseMa - opt.probe(PN(pn)  ).phase, prbNames{PN(pn)}, phasePa - opt.probe(PN(pn)+2).phase, prbNames{PN(pn)+2}); 
        disp(str)

        %%% Plot
        figure(200 + (n-1)*10 + pn)
        clf
        axis square
        box on
        axis([-180 180 -180 180])
        hold on
        grid on
        plot (0,0,':k', 0,0, 'r', 0,0, 'b', 0,0, 'g')
        %legend ('DC [W]', 'l+ [1e7 W/m]', 'l- [1e7 W/m]', 'ls [1e7 W/m]')
        clear lg
        lg(1) = {'DC [W]'};
        for b = 3 : length(PN)
          lg(b-1) = {strcat(char(NC(b)), '[1e7W/m]')};
        end
        legend(lg)
        cdef = ['r', 'b', 'g'];
        clp = ((sigDC(PN(pn),   1) .* cos((ph1 - opt.probe(PN(pn)  ).phase) / 180*pi) ...
            +  sigDC(PN(pn)+1, 1) .* sin((ph1 - opt.probe(PN(pn)  ).phase) / 180*pi)) ...
            + (sigDC(PN(pn)+2, 1) .* cos((ph2 - opt.probe(PN(pn)+2).phase) / 180*pi) ...
            +  sigDC(PN(pn)+3, 1) .* sin((ph2 - opt.probe(PN(pn)+2).phase) / 180*pi))) / 2;
        [C,h] = contour(ph1, ph2, clp, ':k');
        clabel(C,h)
        clear clp;
        for cn = 3 : length(PN)
          cl= (((hL(fp(n)-1, PN(pn),   cn) .* cos((ph1 - opt.probe(PN(pn)  ).phase) / 180*pi) ...
             +  hL(fp(n)-1, PN(pn)+1, cn) .* sin((ph1 - opt.probe(PN(pn)  ).phase) / 180*pi)) ...
             + (hL(fp(n)-1, PN(pn)+2, cn) .* cos((ph2 - opt.probe(PN(pn)+2).phase) / 180*pi) ...
             +  hL(fp(n)-1, PN(pn)+3, cn) .* sin((ph2 - opt.probe(PN(pn)+2).phase) / 180*pi)))) / 2 / 1e7;
          [C,h] = contour(ph1, ph2, cl, cdef(cn-2));
          clabel(C,h)
          clear cl;
        end
        plot(opt.probe(PN(pn)  ).phase, opt.probe(PN(pn)+2).phase, 'ob', 'MarkerFaceColor', cdef(pn-2));
        xlabel('Demodulation Phase of f2-f1 [deg]')
        ylabel('Demodulation Phase of f2+f1 [deg]')
        title([char(NC(LN(pn))) ' signals at ' char(ND(pn)) ' on ' num2str(f(fp(n)-1)) ' Hz'])
        hold off;
        h = gcf;
        for ns = 1 : length(ext)
          saveas(h, [rd '/' num2str(200 + (n-1)*10 + pn) '_DDM_' char(NC(LN(pn)))  '.' char(ext(ns))]);
        end
        
        % Phase compensations
        if abs(phaseMa - opt.probe(PN(pn)  ).phase) > 1
          str = sprintf('%s phase difference at %s is more than 1 degree.', char(NC(LN(pn))), prbNames{PN(pn)});
          disp(str) 
          c1 = input('Do you want to replace old phase to new good phase? or put phase you want in degree y/n/phase[deg] [n]: ', 'S');
          if c1 == 'y' | isreal(c1)
            RePhaseOn = 1;
            phname = strcat('ph', PNr(pn), 'M');
            fid = fopen([char(PFf) '_demph.m'], 'a');
            if c1 == 'y'
              if isempty(findstr('Q', opt.probe(PN(pn)).name))
                fprintf(fid, '%s = %g;\n', char(phname), phaseMa);
              else
                fprintf(fid, '%s = %g;\n', char(phname), phaseMa-90);
              end
            else
              if isempty(findstr('Q', opt.probe(PN(pn)).name))
                fprintf(fid, '%s = %g;\n', char(phname), str2num(c1));
              else
                fprintf(fid, '%s = %g;\n', char(phname), str2num(c1) - 90);
              end
            end
            fclose(fid);
          end    
        end

        if abs(phasePa - opt.probe(PN(pn)+2).phase) > 1
          str = sprintf('%s phase difference at %s is more than 1 degree.', char(NC(LN(pn))), prbNames{PN(pn)+2});
          disp(str) 
          c1 = input('Do you want to replace old phase to new good phase? or put phase you want in degree y/n/phase[deg] [n]: ', 'S');
          if c1 == 'y' | isreal(c1)
            RePhaseOn = 1;
            phname = strcat('ph', PNr(pn), 'P');
            fid = fopen([char(PFf) '_demph.m'], 'a');
            if c1 == 'y'
              if isempty(findstr('Q', opt.probe(PN(pn)).name))
                fprintf(fid, '%s = %g;\n', char(phname), phasePa);
              else
                fprintf(fid, '%s = %g;\n', char(phname), phasePa-90);
              end
            else
              if isempty(findstr('Q', opt.probe(PN(pn)).name))
                fprintf(fid, '%s = %g;\n', char(phname), str2num(c1));
              else
                fprintf(fid, '%s = %g;\n', char(phname), str2num(c1) - 90);
              end
            end
            fclose(fid);
          end    
        end

      end
    end
  end
  
  if RePhaseOn == 1                  
    str = sprintf('\nDem phases have been changed.\nPlease run loopnoise again.');
    disp(str)
    return
  end
