%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script prepares some variables for the loopnoise functions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  %%% some setting parameters

  % root forlder which data is saved
  root = 'results';
  
  % extension to be saved
%  ext = {'png', 'fig', 'emf'};
  ext = {'png', 'pdf', 'fig'};
  
  %%% some constant numbers
  %qeff = 0.93; % quantum effeciency
  qeff = 0.9; % quantum effeciency
  Phv = 2 * opt.h * opt.c / opt.lambda; 
  PdcMAX = [0.1, 2.5, 0.1, 0.1, 0.1]; % Saturation power at all PDs.
  UGF = [30000, 200, 50, 20, 50]; %[Hz]; unity gain frequecy for each loop
  VdcMAX = [0.1, 2.5, 0.1, 0.1, 0.1]; %[V]; maximum DC voltage for demodulated signal
  PDnoise = [1e-9, 1e-9, 1e-9, 1e-9, 1e-9]; %[V/sqrt(Hz)]; electronic noise at demodulated singnal
  MeterUnitOn = 1; % 0: Unit of optical gain is W/m and unit of noise is W/rtHz.
                   % 1: Unit of optical gain is 1/m and unit of noise is 1/rtHz.
                     
  % feed forward parameters. 1 is perfect FF to remove optical cuopling
  % perfectly. Here, reduction factor 30 = 1/(1-0.97) is assumed from iLIGO
  % experience.
  
  %2005 parameters
  FF_Lm2lp = -0.97;
  FF_Lm2lm = -0.97;
  FF_Lm2lsr = -0.97;

  %2009 default parameters
  FF_Lm2lp = 0;
  %FF_Lm2lm = -0.97;
  %FF_Lm2lsr = 0;
  
  % source infomation
  [vFrf, vArf] = getFieldSource(opt);
  aMax = max(abs(vArf));
  nSBa = find(abs(vArf) > aMax / 100);
  nSBb = find(abs(vArf) <= aMax / 100);
  nCA  = find(abs(vArf) == aMax);
  
  % probe names and numbers
  oprb = opt.probe;
  prbNames = {oprb.name};

  % get the serial numbers of probes
  nREFL = strmatch('REFL ', prbNames);
  nREFLb = strmatch('REFLb', prbNames);
  nAS = strmatch('AS', prbNames);
  nOMC = strmatch('OMC ', prbNames);
  nOMCRb = strmatch('OMCRb', prbNames);
  nPOX = strmatch('POX ', prbNames);
  nPOXb = strmatch('POXb', prbNames);
  nPOY = strmatch('POY', prbNames);
  nPOM = strmatch('POM ', prbNames);
  nTRX = strmatch('TRX', prbNames);  
  nTRY = strmatch('TRY', prbNames);  
  nHDa = strmatch('HDa', prbNames);
  nHDb = strmatch('HDb', prbNames);
  
  % get the serial numbers of optics
  nPR = getDriveIndex(opt, 'PR');
  nSR = getDriveIndex(opt, 'SR');
  nBS = getDriveIndex(opt, 'BS');
  nIX = getDriveIndex(opt, 'IX');
  nIY = getDriveIndex(opt, 'IY');
  nEX = getDriveIndex(opt, 'EX');
  nEY = getDriveIndex(opt, 'EY');
  nSrc = getDriveIndex(opt, 'Source');
  nREFLpd = getDriveIndex(opt, 'REFL');
  nREFLbpd = getDriveIndex(opt, 'REFLb');
  nASpd = getDriveIndex(opt, 'AS');
  nOMCpd = getDriveIndex(opt, 'OMC');
  nOMCRbpd = getDriveIndex(opt, 'OMCRb');
  nPOXpd = getDriveIndex(opt, 'POX');
  nPOXbpd = getDriveIndex(opt, 'POXb');
  nPOYpd = getDriveIndex(opt, 'POY');
  nPOMpd = getDriveIndex(opt, 'POM');
  
  % get the serial numbers of vacuums
  nVREI = getDriveIndex(opt, 'VREI');  
  nVREQ = getDriveIndex(opt, 'VREQ');
  nVASI = getDriveIndex(opt, 'VASI');  
  nVASQ = getDriveIndex(opt, 'VASQ');
  nVIXARiI = getDriveIndex(opt, 'VIXARiI');  
  nVIXARiQ = getDriveIndex(opt, 'VIXARiQ');
  nVIXARoI = getDriveIndex(opt, 'VIXARoI');  
  nVIXARoQ = getDriveIndex(opt, 'VIXARoQ');
  nVIYARiI = getDriveIndex(opt, 'VIYARiI');  
  nVIYARiQ = getDriveIndex(opt, 'VIYARiQ');
  nVIYARoI = getDriveIndex(opt, 'VIYARoI');  
  nVIYARoQ = getDriveIndex(opt, 'VIYARoQ');
  nVAttREFLI = getDriveIndex(opt, 'VAttREFLI');  
  nVAttREFLQ = getDriveIndex(opt, 'VAttREFLQ');
  nVAttASI = getDriveIndex(opt, 'VAttASI');  
  nVAttASQ = getDriveIndex(opt, 'VAttASQ');
  nVAttOMCI = getDriveIndex(opt, 'VAttOMCI');  
  nVAttOMCQ = getDriveIndex(opt, 'VAttOMCQ');
  nVAttPOXI = getDriveIndex(opt, 'VAttPOXI');  
  nVAttPOXQ = getDriveIndex(opt, 'VAttPOXQ');

  % PDs producing AC signal for L+, L-, l+, l-, ls respectively. If PD is 
  % for double demodulation(DDM), set PD name as nXXX(4). The number 4 is
  % the first PD of four DDM PDs written in optAdLIGOXXXX.m
  %
  % DC readout : nXXX(1)
  % f1 single demod I : nXXX(2)
  % f1 single demod Q : nXXX(3)
  % double demodulation : nXXX(4)
  % f2 single demod I : nXXX(8)
  % f2 single demod Q : nXXX(9)
  % 3*f1 demod I : nXXX(10)
  % 3*f1 demod Q : nXXX(11)
  % 3*f2 demod I : nXXX(12)
  % 3*f2 demod Q : nXXX(13)
  % 7*f1 demod I : nXXX(14)
  % 7*f1 demod Q : nXXX(15)
  %
  % Currently differential demodulation and double demodulation using Q
  % phase is not supported.
  %PN  = [nREFL(2), nAS(1), nREFLb(4), nREFLb(3), nPOX(2)]; % for AM, PM
  %PN  = [nREFL(2), nOMC(3), nREFLb(4), nREFLb(3), nPOX(2)]; % for AM, PM
  %PN  = [nREFL(2), nOMC(3), nREFLb(4), nOMCRb(4), nPOX(2)]; % for AM, PM
  PN  = [nREFL(2), nOMC(3), nREFLb(4), nOMCRb(4), nPOM(2)]; % 1, for AM, PM, bad, l+ is too big
  %PN  = [nREFL(2), nOMC(3), nREFLb(4), nOMCRb(4), nPOM(4)]; % 2, for AM, PM, same as above
  %PN  = [nREFL(2), nOMC(3), nREFLb(4), nREFLb(3), nPOM(2)]; % bad, l+ is too big, l- coupling is bad
  PN  = [nREFL(2), nOMC(3), nREFLb(4), nOMCRb(4), nPOM(4)]; % for AM, PM, all DDM, bad

  % Names used in graphs showing DOF name.
  NC = {'L+', 'L-', 'l+', 'l-', 'ls'};
  
  % PDs used in DC sweep (DCsweep.m)
  nDC = [nREFL(1) nAS(1) nOMC(1) nPOX(1) nTRX(1) nTRY(1)];

  % Vacuum injection
  VN = [nVREI, nVASI, nVIXARiI, nVIXARoI, nVIYARiI, nVIYARoI, nVAttREFLI,...
        nVAttASI, nVAttOMCI, nVAttPOXI];
  
  % Degrees of freedom
  Lp = 1; Lm = 2; lp = 3; lm = 4; lsr = 5;
  LN = [Lp, Lm, lp, lm, lsr];

  % Fields, names and attenuators at detected port
  for pn = 1 : length(PN)
    clear ttPN
    tPN = opt.probe(PN(pn)).name;
    i = 1; 
    while tPN(i) ~= ' '
      ttPN(i) = tPN(i);
      i = i+1;
    end
    PNr(pn, 1) = {ttPN};
  end

  for pn = 1 : length(PN)
    FN(pn) = getFieldAt(opt, char(PNr(pn)), 'in');  
    AttN(pn) = getDriveIndex(opt, char(strcat('Att', PNr(pn))));  
    if isempty(findstr('IM', opt.probe(PN(pn)).name))
      ND(pn, 1) = prbNames(PN(pn));
    else
      ND(pn, 1) = strcat(PNr(pn), ' DDM');
    end
  end

  % color tables
  colors = [0.0   0.0   1.0;
            1.0   0.0   0.0;
            0.0   0.7   0.0;
            0.6   0.4   0.3;
            0.5   0.5   1.0;
            1.0   0.5   0.0;
            0.7   0.9   0.24;
            0.8   0.8   0.8;
            0.1   0.1   0.6;
            0.95  0.23  0.61;
            0.7   0.7   0.2;
            0.4   0.0   0.1 
            0.6   0.2   0.1;
            0.6   0.6   0.6;
            0.0   0.2   1.0;
            0.6   0.0   0.7;
            0.0   1.0   0.0;
            0.0   0.0   0.0];
  set(0, 'DefaultAxesColorOrder', colors)
