function [ ] = smatrix(opt, f, tVAC, hD, Pdc)
% snr(opt, f, tVAC, hD)
%
% snr.m produces signal to noise sensitivity plots. Signal to noise
% sensitivity(SNR) defined as
%
%   SNR[m/rtHz] = noise from vacuum[W/rtHz] / optical gain[W/m/rtHz]
%
% at a detection port. Detection port is defined as 'PN' in "setup.m".

global rd PFf

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Initial setting

  eval([char(PFf), '_setup']);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%%% Signal to noise
  for pn = 1:length(PN)
    Noise(pn) = sqrt(Phv * Pdc(pn));
    OptG(pn, :) = hD(1, pn, :);
    NOptG(pn, :) = hD(1, pn, :) / hD(1, pn, pn);
    SN(pn, :) = sqrt(Phv * Pdc(pn)) ./ hD(1, pn, :);
  end

fprintf('\n\nThese matrices are available only for broad band configuration.\n')
fprintf('Detuning configuration might produce wrong anser.\n')

fprintf('\n            Shot noise  [W/rtHz]\n')
fprintf('-------------------------------------------------------------\n')
for pn = 1:length(PN)
  fprintf(char(ND(pn)))
  fprintf('     ');
end
fprintf('\n')
for pn = 1:length(PN)
  fprintf('%2.2e   ',Noise(pn))
end
fprintf('\n')

fprintf('\n            Optical gain [W/m] at %f Hz\n', f(1))
fprintf('--------------------------------------------------------------------\n')
fprintf('\tdem.ph');
for pn = 1:length(PN)
  fprintf('\t')
  fprintf(char(NC(pn)))
  fprintf('       ')
end
fprintf('\n')
for pn = 1:length(PN)
  fprintf(char(ND(pn)))
  lND = length(char(ND(pn)));
  fprintf('\t')
  if isempty(findstr('IM', opt.probe(PN(pn)).name))
    if isempty(findstr('DC', opt.probe(PN(pn)).name))
      % single
      fprintf('%2.0f', opt.probe(PN(pn)).phase)
    else
      %DC
    end
  else
    % DDM
    fprintf('%2.0f,%2.0f', opt.probe(PN(pn)).phase, opt.probe(PN(pn) + 2).phase)
    if (opt.probe(PN(pn)).phase < 100 && opt.probe(PN(pn)).phase > 0) |...
       (opt.probe(PN(pn) + 2).phase < 100 && opt.probe(PN(pn) + 2).phase > 0)
    end
  end
  fprintf('\t%2.2e', OptG(pn, :))
  fprintf('\n')
end

fprintf('\n            Normalized Optical gain at %f Hz\n', f(1))
fprintf('--------------------------------------------------------------------\n')
fprintf('\tdem.ph');
for pn = 1:length(PN)
  fprintf('\t')
  fprintf(char(NC(pn)))
  fprintf('       ')
end
fprintf('\n')
for pn = 1:length(PN)
  fprintf(char(ND(pn)))
  lND = length(char(ND(pn)));
  fprintf('\t')
  if isempty(findstr('IM', opt.probe(PN(pn)).name))
    if isempty(findstr('DC', opt.probe(PN(pn)).name))
      % single
      fprintf('%2.0f', opt.probe(PN(pn)).phase)
    else
      %DC
    end
  else
    % DDM
    fprintf('%2.0f, %2.0f', opt.probe(PN(pn)).phase, opt.probe(PN(pn) + 2).phase)
    if (opt.probe(PN(pn)).phase < 100 && opt.probe(PN(pn)).phase > 0) |...
       (opt.probe(PN(pn) + 2).phase < 100 && opt.probe(PN(pn) + 2).phase > 0)
    end
  end
  fprintf('\t%2.2e', NOptG(pn, :))
  fprintf('\n')
end

fprintf('\n            Shot noise limited sensitivity [m/rHz] at %f Hz\n', f(1))
fprintf('--------------------------------------------------------------------\n')
fprintf('       ');
fprintf('\tdem.ph');
for pn = 1:length(PN)
  fprintf('\t')
  fprintf(char(NC(pn)))
  fprintf('       ')
end
fprintf('\n')
for pn = 1:length(PN)
  fprintf(char(ND(pn)))
  lND = length(char(ND(pn)));
  fprintf('\t')
  if isempty(findstr('IM', opt.probe(PN(pn)).name))
    if isempty(findstr('DC', opt.probe(PN(pn)).name))
      % single
      fprintf('%2.0f', opt.probe(PN(pn)).phase)
    else
      %DC
    end
  else
    % DDM
    fprintf('%2.0f, %2.0f', opt.probe(PN(pn)).phase, opt.probe(PN(pn) + 2).phase)
    if (opt.probe(PN(pn)).phase < 100 && opt.probe(PN(pn)).phase > 0) |...
       (opt.probe(PN(pn) + 2).phase < 100 && opt.probe(PN(pn) + 2).phase > 0)
    end
  end
  fprintf('\t%2.2e', SN(pn, :))
  fprintf('\n')
end
fprintf('\n')


